<?php

namespace Permadi\Kompetensi\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Permadi\Kompetensi\Models\Kompetensi;

class KompetensiPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the kompetensi.
     *
     * @param User $user
     * @param Kompetensi $kompetensi
     *
     * @return bool
     */
    public function view(User $user, Kompetensi $kompetensi)
    {
        if ($user->canDo('kompetensi.kompetensi.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $kompetensi->user_id;
    }

    /**
     * Determine if the given user can create a kompetensi.
     *
     * @param User $user
     * @param Kompetensi $kompetensi
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('kompetensi.kompetensi.create');
    }

    /**
     * Determine if the given user can update the given kompetensi.
     *
     * @param User $user
     * @param Kompetensi $kompetensi
     *
     * @return bool
     */
    public function update(User $user, Kompetensi $kompetensi)
    {
        if ($user->canDo('kompetensi.kompetensi.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $kompetensi->user_id;
    }

    /**
     * Determine if the given user can delete the given kompetensi.
     *
     * @param User $user
     * @param Kompetensi $kompetensi
     *
     * @return bool
     */
    public function delete(User $user, Kompetensi $kompetensi)
    {
        if ($user->canDo('kompetensi.kompetensi.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $kompetensi->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
