<?php

namespace Permadi\Kompetensi\Providers;

use Illuminate\Support\ServiceProvider;

class KompetensiServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'kompetensi');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'kompetensi');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('kompetensi', function ($app) {
            return $this->app->make('Permadi\Kompetensi\Kompetensi');
        });

        // Bind Kompetensi to repository
        $this->app->bind(
            \Permadi\Kompetensi\Interfaces\KompetensiRepositoryInterface::class,
            \Permadi\Kompetensi\Repositories\Eloquent\KompetensiRepository::class
        );

        $this->app->register(\Permadi\Kompetensi\Providers\AuthServiceProvider::class);
        $this->app->register(\Permadi\Kompetensi\Providers\EventServiceProvider::class);
        $this->app->register(\Permadi\Kompetensi\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['kompetensi'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/kompetensi.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__ . '/../../../../resources/views/public'  => base_path('resources/views/vendor/kompetensi/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views/admin' => base_path('resources/views/vendor/kompetensi/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/kompetensi')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
